//-------------------------------------------------------------------------------------------------
// <copyright file="WixBuildPropertyPagePanel.cs" company="Microsoft">
//    Copyright (c) Microsoft Corporation.  All rights reserved.
//    
//    The use and distribution terms for this software are covered by the
//    Common Public License 1.0 (http://opensource.org/licenses/cpl.php)
//    which can be found in the file CPL.TXT at the root of this distribution.
//    By using this software in any fashion, you are agreeing to be bound by
//    the terms of this license.
//    
//    You must not remove this notice, or any other, from this software.
// </copyright>
// 
// <summary>
// Contains the WixBuildPropertyPagePanel class.
// </summary>
//-------------------------------------------------------------------------------------------------

namespace Microsoft.Tools.WindowsInstallerXml.VisualStudio.PropertyPages
{
    using System;
    using System.Diagnostics;
    using System.Text;
    using System.Windows.Forms;

    using Microsoft.Tools.WindowsInstallerXml.VisualStudio.Forms;
    using System.ComponentModel;

    /// <summary>
    /// Property page contents for the Candle Settings page.
    /// </summary>
    internal partial class WixBuildPropertyPagePanel : WixPropertyPagePanel
    {
        // =========================================================================================
        // Member Variables
        // =========================================================================================

        private const string DebugDefine = "Debug";

        // =========================================================================================
        // Constructors
        // =========================================================================================

        /// <summary>
        /// Initializes a new instance of the <see cref="WixBuildPropertyPagePanel"/> class.
        /// </summary>
        /// <param name="parentPropertyPage">The parent property page to which this is bound.</param>
        public WixBuildPropertyPagePanel(WixPropertyPage parentPropertyPage)
            : base(parentPropertyPage)
        {
            this.InitializeComponent();

            this.culturesTextBox.Tag = WixProjectFileConstants.Cultures;
            this.defineConstantsTextBox.Tag = WixProjectFileConstants.DefineConstants;
            this.defineDebugCheckBox.Tag = WixProjectFileConstants.DefineDebugConstant;
            this.defineVariablesTextBox.Tag = WixProjectFileConstants.WixVariables;
            this.leaveTempFilesCheckBox.Tag = WixProjectFileConstants.LeaveTemporaryFiles;
            this.outputPathFolderBrowser.TextBox.Tag = WixProjectFileConstants.OutputPath;
            this.suppressedWarningsText.Tag = WixProjectFileConstants.SuppressSpecificWarnings;
            this.suppressWixPdbCheckBox.Tag = WixProjectFileConstants.SuppressPdbOutput;
            this.verboseOutputCheckBox.Tag = WixProjectFileConstants.VerboseOutput;
            this.warningsAsErrorsCheckBox.Tag = WixProjectFileConstants.TreatWarningsAsErrors;
            this.warningLevelCombo.Tag = WixProjectFileConstants.WarningLevel;

            this.warningLevelCombo.SelectedIndexChanged += delegate
            {
                this.suppressedWarningsText.Enabled = this.warningLevelCombo.SelectedIndex != 0;
                this.warningsAsErrorsCheckBox.Enabled = this.warningLevelCombo.SelectedIndex != 0;
            };
        }

        // =========================================================================================
        // Methods
        // =========================================================================================

        /// <summary>
        /// Binds the properties from the MSBuild project file to the controls on the property page.
        /// </summary>
        protected internal override void BindProperties()
        {
            base.BindProperties();

            WixOutputType projectType = this.ParentPropertyPage.ProjectMgr.OutputType;
            this.defineVariablesTextBox.Enabled = (projectType != WixOutputType.Library);
            this.culturesTextBox.Enabled = (projectType != WixOutputType.Library);
            this.leaveTempFilesCheckBox.Enabled = (projectType != WixOutputType.Library);
            this.suppressWixPdbCheckBox.Enabled = (projectType != WixOutputType.Library);
            this.bindFilesCheckBox.Enabled = (projectType == WixOutputType.Library);

            this.suppressedWarningsText.Enabled = this.warningLevelCombo.SelectedIndex != 0;
            this.warningsAsErrorsCheckBox.Enabled = this.warningLevelCombo.SelectedIndex != 0;
        }
    }
}
