﻿//-----------------------------------------------------------------------
// <copyright file="WixprojMSBuild.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
//    
//    The use and distribution terms for this software are covered by the
//    Common Public License 1.0 (http://opensource.org/licenses/cpl.php)
//    which can be found in the file CPL.TXT at the root of this distribution.
//    By using this software in any fashion, you are agreeing to be bound by
//    the terms of this license.
//    
//    You must not remove this notice, or any other, from this software.
// </copyright>
// <summary>A class that uses MSBuild to build a .wixproj</summary>
//-----------------------------------------------------------------------

namespace Microsoft.Tools.WindowsInstallerXml.Test
{
    using System;
    using System.Collections.Generic;
    using System.IO;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    /// <summary>
    /// A class that uses MSBuild to build a .wixproj
    /// </summary>
    public partial class WixprojMSBuild : MSBuild
    {
        /// <summary>
        /// Constructor that uses the default location for MSBuild.
        /// </summary>
        public WixprojMSBuild()
            : base()
        {
            this.Initialize();
        }

        /// <summary>
        /// Constructor that uses the default location for MSBuild.
        /// </summary>
        /// <param name="outputPath">The MSBuild OutputPath property</param>
        public WixprojMSBuild(string outputPath)
            : this()
        {
            this.Properties.Add("OutputPath", outputPath);
        }

        /// <summary>
        /// Constructor that accepts a path to the MSBuild location.
        /// </summary>
        /// <param name="toolDirectory">The directory of MSBuild.exe.</param>
        /// <param name="outputPath">The MSBuild OutputPath property</param>
        public WixprojMSBuild(string toolDirectory, string outputPath)
            : base(toolDirectory)
        {
            this.Initialize();
            this.Properties.Add("OutputPath", outputPath);
        }

        /// <summary>
        /// Perform some initialization for this class
        /// </summary>
        private void Initialize()
        {
            this.ExpectedExitCode = 0;
        }
    }
}
