//-----------------------------------------------------------------------
// <copyright file="FileTests.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
//    
//    The use and distribution terms for this software are covered by the
//    Common Public License 1.0 (http://opensource.org/licenses/cpl.php)
//    which can be found in the file CPL.TXT at the root of this distribution.
//    By using this software in any fashion, you are agreeing to be bound by
//    the terms of this license.
//    
//    You must not remove this notice, or any other, from this software.
// </copyright>
// <summary>Tests for authoring files into a package</summary>
//-----------------------------------------------------------------------

namespace Microsoft.Tools.WindowsInstallerXml.Test.Tests.Integration.BuildingPackages.Files
{
    using System;
    using System.IO;
    using System.Text;
    using System.Collections.Generic;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    using Microsoft.Tools.WindowsInstallerXml.Test;

    /// <summary>
    /// Tests for authoring files into a package
    /// </summary>
    [TestClass]
    public class FileTests
    {
        private static readonly string TestDataDirectory = Environment.ExpandEnvironmentVariables(@"%WIX%\test\data\Integration\BuildingPackages\Files\FileTests");

        [TestMethod]
        [Description("Verify the simple use of the File element")]
        [Priority(1)]
        public void SimpleFile()
        {
            string sourceFile = Path.Combine(FileTests.TestDataDirectory, @"SimpleFile\product.wxs");
            string msi = Builder.BuildPackage(sourceFile, "test.msi");
            Verifier.VerifyResults(Path.Combine(FileTests.TestDataDirectory, @"SimpleFile\expected.msi"), msi);
        }

        [TestMethod]
        [Description("Verify a companion file can be specified")]
        [Priority(2)]
        [Ignore]
        public void CompanionFile()
        {
        }

        [TestMethod]
        [Description("Verify that the publicKeyToken in the MsiAssemblyName table is not 'NEUTRAL'")]
        [TestProperty("Bug Link", "http://sourceforge.net/tracker/index.php?func=detail&aid=1801826&group_id=105970&atid=642714")]
        [Priority(3)]
        public void AssemblyNullPublicKey()
        { 
            // Run Candle
            Candle candle = new Candle();
            candle.SourceFiles.Add(Path.Combine(FileTests.TestDataDirectory, @"AssemblyNullPublicKey\product.wxs"));
            candle.Run();

            // Run Light
            Light light = new Light(candle);

            string assembly1 = Path.Combine(WixTests.SharedFilesDirectory, @"TestBinaries\bin\Assembly1.dll");
            light.ExpectedWixMessages.Add(new WixMessage(282, String.Format("Assembly {0} in component Component1 has no strong name and has been marked to be placed in the GAC. All assemblies installed to the GAC must have a valid strong name.", assembly1), WixMessage.MessageTypeEnum.Error));
            light.ExpectedExitCode = 282;
            
            light.Run();
        }
    }
}